@@ -139,9 +139,6 @@ get_glyph_attrs <- function(spec, dat = NULL) {
   if (!is.null(glyph_attrs$text))
     glyph_attrs$text$field <- glyph_attrs$text$field$field
 
-  if (!is.null(glyph_attrs$visible))
-    glyph_attrs$visible <- glyph_attrs$visible$value
-
   glyph_attrs
 }
 
@@ -149,7 +146,7 @@ data_model <- function(dd, id = NULL) {
   res <- base_model_object("ColumnDataSource", id)
 
   res$model$attributes$column_names <- I(names(dd))
-  res$model$attributes$selected <- I(NULL)
+  res$model$attributes$selected <- list()
   res$model$attributes$data <- as.list(dd)
 
   res
