@@ -16,7 +16,7 @@ ly_polygons <- function(
   fig, xs, ys, group = NULL, data = figure_data(fig),
   color = NULL, alpha = 1,
   hover = NULL, url = NULL, # legend = NULL,
-  lname = NULL, lgroup = NULL, visible = TRUE, ...
+  lname = NULL, lgroup = NULL, ...
 ) {
 
   validate_fig(fig, "ly_polygons")
@@ -32,7 +32,6 @@ ly_polygons <- function(
       url,
       lname,
       lgroup,
-      visible,
       dots = lazy_dots(...)
     )
   )
@@ -137,7 +136,7 @@ ly_rect <- function(
   data = figure_data(fig),
   color = NULL, alpha = 1,
   hover = NULL, url = NULL, legend = NULL,
-  lname = NULL, lgroup = NULL, visible = TRUE, ...
+  lname = NULL, lgroup = NULL, ...
 ) {
 
   validate_fig(fig, "ly_rect")
@@ -154,7 +153,6 @@ ly_rect <- function(
       url,
       lname,
       lgroup,
-      visible,
       dots = lazy_dots(...)
     )
   )
@@ -220,7 +218,7 @@ ly_crect <- function(
   width = 1, height = 1, angle = 0, dilate = FALSE,
   color = NULL, alpha = 1,
   hover = NULL, url = NULL, legend = NULL,
-  lname = NULL, lgroup = NULL, visible = TRUE, ...) {
+  lname = NULL, lgroup = NULL, ...) {
 
   validate_fig(fig, "ly_crect")
 
@@ -238,7 +236,6 @@ ly_crect <- function(
       url,
       lname,
       lgroup,
-      visible,
       dots = lazy_dots(...)
     )
   )
@@ -299,7 +296,7 @@ ly_oval <- function(
   fig, x, y = NULL, data = figure_data(fig),
   width = 0.1, height = 0.1, angle = 0,
   color = NULL, alpha = 1,
-  legend = NULL, lname = NULL, lgroup = NULL, visible = TRUE,
+  legend = NULL, lname = NULL, lgroup = NULL,
   ...
 ) {
 
@@ -319,7 +316,6 @@ ly_oval <- function(
       legend,
       lname,
       lgroup,
-      visible,
       dots = lazy_dots(...)
     )
   )
@@ -367,7 +363,7 @@ ly_patch <- function(
   fig, x, y, data = figure_data(fig),
   color = NULL, alpha = 1,
   hover = NULL, url = NULL,
-  legend = NULL, lname = NULL, lgroup = NULL, visible = TRUE,
+  legend = NULL, lname = NULL, lgroup = NULL,
   ...) {
 
   validate_fig(fig, "ly_patch")
@@ -383,7 +379,6 @@ ly_patch <- function(
       legend,
       lname,
       lgroup,
-      visible,
       dots = lazy_dots(...)
     )
   )
