@@ -5,7 +5,7 @@
 #' @param file parameter passed on to \code{\link[base]{cat}}
 #' @param pbcopy logical - if on OSX, should the results be passed to the clipboard (TRUE) instead of printed to the screen (FALSE)?
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' p <- figure() %>% ly_points(1:10) %>%
 #'  tool_pan(dimensions = "height")
 #' print_model_json(p)
@@ -13,12 +13,12 @@
 #' @importFrom jsonlite toJSON
 #' @export
 print_model_json <- function(fig, prepare = TRUE, pretty = TRUE, file = "", pbcopy = FALSE) {
-  if(prepare) {
+  if (prepare) {
     fig <- rbokeh_prerender(fig)
   }
 
-  if(pbcopy)
+  if (pbcopy)
     file <- pipe("pbcopy")
-  cat(toJSON(fig$x$docs_json, pretty = pretty,
+  cat(jsonlite::toJSON(fig$x$docs_json, pretty = pretty,
     auto_unbox = TRUE, null = "null", na = "null"), "\n", file = file)
 }
