@@ -106,7 +106,7 @@ test_that("examples", {
     ly_image(volcano, palette = blues9)
   print_model_json(p[[20]], file = fname)
 
-  url <- c("http://bokeh.pydata.org/en/latest/_static/images/logo.png",
+  url <- c("http://docs.bokeh.org/en/latest/_static/images/logo.png",
     "http://developer.r-project.org/Logo/Rlogo-4.png")
 
   ss <- seq(0, 2 * pi, length = 13)[-1]
